"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
function wrap(formatter, dst) {
    return (results) => {
        const output = formatter(results);
        if (dst) {
            const dir = path_1.default.dirname(dst);
            if (!fs_1.default.existsSync(dir)) {
                fs_1.default.mkdirSync(dir, { recursive: true });
            }
            fs_1.default.writeFileSync(dst, output, "utf-8");
            return null;
        }
        else {
            return output;
        }
    };
}
function getFormatter(formatters) {
    const fn = formatters.split(",").map(cur => {
        const [name, dst] = cur.split("=", 2);
        const moduleName = name.replace(/[^a-z]+/g, "");
        const formatter = require(`../formatters/${moduleName}`);
        return wrap(formatter, dst);
    });
    return (report) => {
        return fn
            .map((formatter) => formatter(report.results))
            .filter(Boolean)
            .join("\n");
    };
}
exports.getFormatter = getFormatter;
