"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rule_1 = require("../rule");
class PreferButton extends rule_1.Rule {
    documentation() {
        return {
            description: `Prefer to use the generic \`<button>\` element instead of \`<input>\`.`,
            url: rule_1.ruleDocumentationUrl(__filename),
        };
    }
    setup() {
        this.on("tag:close", (event) => {
            const node = event.previous;
            /* only handle input elements */
            if (node.tagName !== "input") {
                return;
            }
            const type = node.getAttribute("type");
            /* sanity check: handle missing and boolean attributes */
            if (!type || type.value === null) {
                return;
            }
            if (type.valueMatches(/^(button|submit|reset|image)$/, false)) {
                this.report(node, `Prefer to use <button> instead of <input type="${type.value}"> when adding buttons`, type.valueLocation);
            }
        });
    }
}
module.exports = PreferButton;
